@@ -74,7 +74,14 @@ class ApplicationLoadBalancerEndpoint(
         :param weight: Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ApplicationLoadBalancerEndpoint.__init__)
+            def stub(
+                load_balancer: aws_cdk.aws_elasticloadbalancingv2.IApplicationLoadBalancer,
+                *,
+                preserve_client_ip: typing.Optional[builtins.bool] = None,
+                weight: typing.Optional[jsii.Number] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument load_balancer", value=load_balancer, expected_type=type_hints["load_balancer"])
         options = ApplicationLoadBalancerEndpointOptions(
             preserve_client_ip=preserve_client_ip, weight=weight
@@ -132,7 +139,13 @@ class ApplicationLoadBalancerEndpointOptions:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ApplicationLoadBalancerEndpointOptions.__init__)
+            def stub(
+                *,
+                preserve_client_ip: typing.Optional[builtins.bool] = None,
+                weight: typing.Optional[jsii.Number] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument preserve_client_ip", value=preserve_client_ip, expected_type=type_hints["preserve_client_ip"])
             check_type(argname="argument weight", value=weight, expected_type=type_hints["weight"])
         self._values: typing.Dict[str, typing.Any] = {}
@@ -214,7 +227,13 @@ class CfnEipEndpoint(
         :param weight: Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnEipEndpoint.__init__)
+            def stub(
+                eip: aws_cdk.aws_ec2.CfnEIP,
+                *,
+                weight: typing.Optional[jsii.Number] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument eip", value=eip, expected_type=type_hints["eip"])
         options = CfnEipEndpointProps(weight=weight)
 
@@ -263,7 +282,9 @@ class CfnEipEndpointProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnEipEndpointProps.__init__)
+            def stub(*, weight: typing.Optional[jsii.Number] = None) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument weight", value=weight, expected_type=type_hints["weight"])
         self._values: typing.Dict[str, typing.Any] = {}
         if weight is not None:
@@ -330,7 +351,14 @@ class InstanceEndpoint(
         :param weight: Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(InstanceEndpoint.__init__)
+            def stub(
+                instance: aws_cdk.aws_ec2.IInstance,
+                *,
+                preserve_client_ip: typing.Optional[builtins.bool] = None,
+                weight: typing.Optional[jsii.Number] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument instance", value=instance, expected_type=type_hints["instance"])
         options = InstanceEndpointProps(
             preserve_client_ip=preserve_client_ip, weight=weight
@@ -388,7 +416,13 @@ class InstanceEndpointProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(InstanceEndpointProps.__init__)
+            def stub(
+                *,
+                preserve_client_ip: typing.Optional[builtins.bool] = None,
+                weight: typing.Optional[jsii.Number] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument preserve_client_ip", value=preserve_client_ip, expected_type=type_hints["preserve_client_ip"])
             check_type(argname="argument weight", value=weight, expected_type=type_hints["weight"])
         self._values: typing.Dict[str, typing.Any] = {}
@@ -486,7 +520,13 @@ class NetworkLoadBalancerEndpoint(
         :param weight: Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NetworkLoadBalancerEndpoint.__init__)
+            def stub(
+                load_balancer: aws_cdk.aws_elasticloadbalancingv2.INetworkLoadBalancer,
+                *,
+                weight: typing.Optional[jsii.Number] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument load_balancer", value=load_balancer, expected_type=type_hints["load_balancer"])
         options = NetworkLoadBalancerEndpointProps(weight=weight)
 
@@ -535,7 +575,9 @@ class NetworkLoadBalancerEndpointProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NetworkLoadBalancerEndpointProps.__init__)
+            def stub(*, weight: typing.Optional[jsii.Number] = None) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument weight", value=weight, expected_type=type_hints["weight"])
         self._values: typing.Dict[str, typing.Any] = {}
         if weight is not None:
